# Changelog

## 0.1.0 (2025-09-08)


### Bug Fixes

* ci tool build error ([#8](https://github.com/circlefin/circle-ooak/issues/8)) ([fd64f61](https://github.com/circlefin/circle-ooak/commit/fd64f611d32e0bc6c8129fa9dd8b365163996c79))


### Miscellaneous Chores

* **TECHOPS-18898:** add release pipeine ([#6](https://github.com/circlefin/circle-ooak/issues/6)) ([84e6b40](https://github.com/circlefin/circle-ooak/commit/84e6b4036114ffbc6d63cbb96352279d7a6b4e35))
* **TECHOPS-18898:** fix gpg agent error in release workflow ([#16](https://github.com/circlefin/circle-ooak/issues/16)) ([503ac51](https://github.com/circlefin/circle-ooak/commit/503ac51b103e0647d302e07d9371de7c8639d724))
* **TECHOPS-18898:** fix tests ([#7](https://github.com/circlefin/circle-ooak/issues/7)) ([d83fff4](https://github.com/circlefin/circle-ooak/commit/d83fff4c05f1e5008406c727ca1cac3f6499e1f6))
* **TECHOPS-18898:** publish using release please ([#13](https://github.com/circlefin/circle-ooak/issues/13)) ([486c320](https://github.com/circlefin/circle-ooak/commit/486c320352ec1eff392c792b91f123ce4b6a0bb9))
* **TECHOPS-18898:** use conventional commits and attach github release assets ([#9](https://github.com/circlefin/circle-ooak/issues/9)) ([dba08f5](https://github.com/circlefin/circle-ooak/commit/dba08f54b5661a31fead25c94637eb2caeb20644))
* **TECHOPS-19100:** fix ci ([#10](https://github.com/circlefin/circle-ooak/issues/10)) ([552bde8](https://github.com/circlefin/circle-ooak/commit/552bde8416413efe214eb20562e55d70a3fbe1a9))
* **TECHOPS-19100:** switch to public worfklow tokens ([#11](https://github.com/circlefin/circle-ooak/issues/11)) ([d0ac119](https://github.com/circlefin/circle-ooak/commit/d0ac119acd17584b1cac9c0f58e08c524be01385))
